/*******************************************************************************
 mp4_pubpoint.h - A library for pushing/polling input/output Fragmented MPEG4

 Copyright (C) 2010-2020 CodeShop B.V.
 http://www.code-shop.com

 For licensing see the LICENSE file
******************************************************************************/

#ifndef MP4_PUBPOINT_H_AKW
#define MP4_PUBPOINT_H_AKW

#include "mod_streaming_export.h"
#include "http_util.h"
#include <inttypes.h>

#ifdef __cplusplus
extern "C" {
#endif

struct buckets_t;
struct mp4_split_options_t;

struct mp4_process_context_t;

MP4_DLL_EXPORT
post_handler_t* pubpoint_input_stream_init(mp4_process_context_t* ctx);

MP4_DLL_EXPORT
post_handler_t* pubpoint_mpegts_stream_init(mp4_process_context_t*, int is_playlist);

// pubpoint_push_input_stream ingests media data.
//
// [first, last>
// The media data.
//
// result_text
// In case of an error, holds additional information.
//
// Return value:
// 200 OK.
//
// 400 Bad Request
// - Error parsing URL
//
// 403 Forbidden
// - Unable to make file mapping. Most likely cause is that the webserver
//   does not have permission to read/write to the file/directory.
//
// 404 Not Found
// - Stream not found.
//
// 409 Conflict
// - Publishing to a stream which has previously been closed.
//
// 412 Precondition Failed
// - Requested fragment not yet available.
//
// 415 Unsupported Media Type
// - Invalid stream box.
// - Missing tfhd box in media fragment.
// - Missing tfxd box in media fragment.
// - Detected corrupt box in media fragment.
// - Box too large in media fragment.
//
// 500 Internal Server Error
// - Not enough memory.
//

#ifdef __cplusplus
} /* extern C definitions */
#endif

#endif // MP4_PUBPOINT_H_AKW

// End Of File

